@@ -22,11 +22,11 @@
 #' estimation (e.g., Geenenens et al., 2014), \cr
 #' \code{"TLL1"}: transformation estimator with log-linear local likelihood
 #' estimation (Geenenens et al., 2014), \cr
-#' \code{"TLL2"}: transformation estimator with log-quadradtic local likelihood
+#' \code{"TLL2"}: transformation estimator with log-quadratic local likelihood
 #' estimation (Geenenens et al., 2014), \cr
 #' \code{"TLL1nn"}: transformation estimator with log-linear local likelihood
 #' estimation and nearest-neighbor bandwidths (Geenenens et al., 2014), \cr
-#' \code{"TLL2nn"}: transformation estimator with log-quadradtic local likelihood
+#' \code{"TLL2nn"}: transformation estimator with log-quadratic local likelihood
 #' estimation and nearest-neighbor bandwidths (Geenenens et al., 2014), \cr
 #' \code{"TTPI"}: tapered transformation estimator with plug-in bandwidths
 #' (Wu and Wen, 2015), \cr
@@ -82,19 +82,22 @@
 #' was kindly provided by Kuangyu Wen.
 #'
 #' @author Thomas Nagler
-#'
-#' @seealso
-#' \code{\link{kdecopula}},
-#' \code{\link{plot.kdecopula}},
-#' \code{\link{dkdecop}},
-#' \code{\link{pkdecop}},
-#' \code{\link{rkdecop}}
-#'
-#' @references
-#' Geenens, G., Charpentier, A., and Paindaveine, D. (2014).
+#' 
+#' @seealso 
+#' \code{\link[kdecopula:kdecopula]{kdecopula}},
+#' \code{\link[kdecopula:plot.kdecopula]{plot.kdecopula}},
+#' \code{\link[kdecopula:predict.kdecopula]{predict.kdecopula}},
+#' \code{\link[kdecopula:fitted.kdecopula]{fitted.kdecopula}},
+#' \code{\link[kdecopula:simulate.kdecopula]{simulate.kdecopula}},
+#' \code{\link[kdecopula:dkdecop]{dkdecop}},
+#' \code{\link[kdecopula:pkdecop]{pkdecop}},
+#' \code{\link[kdecopula:rkdecop]{rkdecop}}
+#' 
+#' @references 
+#' Geenens, G., Charpentier, A., and Paindaveine, D. (2017).
 #' Probit transformation for nonparametric kernel estimation of the copula
 #' density.
-#' arXiv:1404.4414 [stat.ME].
+#' Bernoulli, 23(3), 1848-1873. 
 #' \cr \cr
 #' Wen, K. and Wu, X. (2015).
 #' Transformation-Kernel Estimation of the Copula Density,
@@ -111,7 +114,7 @@
 #' \cr \cr
 #' Weiss, G. and Scheffer, M. (2012).
 #' Smooth Nonparametric Bernstein Vine Copulas.
-#' arXiv:1210.2043 [q-fin.RM]
+#' arXiv:1210.2043
 #' \cr \cr
 #' Nagler, T. (2014).
 #' Kernel Methods for Vine Copula Estimation.
@@ -122,23 +125,23 @@
 #'
 #' ## load data and transform with empirical cdf
 #' data(wdbc)
-#' udat <- apply(wdbc[, -1], 2, function(x) rank(x)/(length(x)+1))
+#' udat <- apply(wdbc[, -1], 2, function(x) rank(x) / (length(x) + 1))
 #'
 #' ## estimation of copula density of variables 5 and 6
-#' est <- kdecop(udat[, 5:6])
-#' summary(est)
-#' plot(est)
-#' contour(est)
+#' fit <- kdecop(udat[, 5:6])
+#' summary(fit)
+#' plot(fit)
+#' contour(fit)
 #'
 #' ## evaluate density estimate at (u1,u2)=(0.123,0.321)
-#' dkdecop(c(0.123, 0.321), est)
+#' dkdecop(c(0.123, 0.321), fit)
 #'
 #' ## evaluate cdf estimate at (u1,u2)=(0.123,0.321)
-#' pkdecop(c(0.123, 0.321), est)
+#' pkdecop(c(0.123, 0.321), fit)
 #'
 #' ## simulate 500 samples from density estimate
-#' plot(rkdecop(500, est))  # pseudo-random
-#' plot(rkdecop(500, est, quasi = TRUE))  # quasi-random
+#' plot(rkdecop(500, fit))  # pseudo-random
+#' plot(rkdecop(500, fit, quasi = TRUE))  # quasi-random
 #'
 #'
 #' @import lattice
@@ -146,7 +149,8 @@
 #' @importFrom graphics contour plot
 #'
 #' @export
-kdecop <- function(udata, bw = NA, mult = 1, method = "TLL2", knots = 30,
+#' 
+kdecop <- function(udata, bw = NA, mult = 1, method = "TLL2nn", knots = 30, 
                    renorm.iter = 3L, info = TRUE) {
     udata <- as.matrix(udata)
     n <- NROW(udata)
@@ -252,8 +256,8 @@ renorm2unif <- function(vals, grid, renorm.iter) {
     if (renorm.iter > 0) {
         d <- NCOL(grid$expanded)
         knots <- length(grid$pnts)
-        tmplst <- split(rep(seq.int(knots)-1, d-1),
-                        ceiling(seq.int(knots*(d-1))/knots))
+        tmplst <- split(rep(seq.int(knots) - 1, d - 1),
+                        ceiling(seq.int(knots * (d - 1)) / knots))
         helpind <- as.matrix(do.call(expand.grid, tmplst))
         vals <- renorm(vals, grid$pnts, renorm.iter, helpind)
     }
@@ -275,7 +279,7 @@ with_fit_info <- function(res, info, lfit) {
         # log-likelihood
         likvalues <- dkdecop(res$udata, res)
         loglik <- sum(log(likvalues))
-        if (!(res$method %in% c("TTPI", "TTCV", "bern"))) {
+        if (!(res$method %in% c("TTPI", "TTCV"))) {
             # effective number of parameters
             effp <- eff_num_par(res$udata,
                                 likvalues,
@@ -283,10 +287,10 @@ with_fit_info <- function(res, info, lfit) {
                                 res$method,
                                 lfit)
             # information criteria
-            AIC  <- - 2 * loglik + 2 * effp
+            AIC  <- -2 * loglik + 2 * effp
             n <- nrow(res$udata)
             cAIC <- AIC + (2 * effp * (effp + 1)) / (n - effp - 1)
-            BIC  <- - 2 * loglik + log(n) * effp
+            BIC  <- -2 * loglik + log(n) * effp
         } else {
             effp <- AIC <- cAIC <- BIC <- NA
         }
